@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::ListId;
-$Config::Model::ListId::VERSION = '2.117';
+$Config::Model::ListId::VERSION = '2.126';
 use 5.10.1;
 use Mouse;
 
@@ -22,6 +22,7 @@ with "Config::Model::Role::Grab";
 with "Config::Model::Role::ComputeFunction";
 
 my $logger = get_logger("Tree::Element::Id::List");
+my $user_logger = get_logger("User");
 
 has data => (
     is      => 'rw',
@@ -49,8 +50,15 @@ sub BUILD {
     }
 
     if ( defined $self->{migrate_keys_from} ) {
-        warn $self->name, "Using migrate_keys_from with list element is deprecated.",
-            " Use migrate_values_from\n";
+        if ($::_use_log4perl_to_warn) {
+            $user_logger->warn(
+                $self->name, "Using migrate_keys_from with ",
+                "list element is deprecated. Use migrate_values_from");
+        }
+        else {
+            warn $self->name, "Using migrate_keys_from with list element is deprecated.",
+                " Use migrate_values_from\n";
+        }
     }
 
     # Supply the mandatory parameter
@@ -509,7 +517,7 @@ Config::Model::ListId - Handle list element for configuration model
 
 =head1 VERSION
 
-version 2.117
+version 2.126
 
 =head1 SYNOPSIS
 
